.. _basis_sets:

Basis sets
==========

.. autoclass:: mumott.methods.basis_sets.SphericalHarmonics
   :members:
   :inherited-members:


.. autoclass:: mumott.methods.basis_sets.TrivialBasis
   :members:
   :undoc-members:
   :inherited-members:

.. autoclass:: mumott.methods.basis_sets.GaussianKernels
   :members:
   :undoc-members:
   :inherited-members:
